<?php

// ----------------------------------------------------------------------
function debug($s)
// ----------------------------------------------------------------------
{
  if ( $_ENV['DEBUG'] != '' ) {
    echo 'DEBUG: ' . $s . "\n";
  }
}

// ----------------------------------------------------------------------
function error($s)
// ----------------------------------------------------------------------
{
  echo 'ERROR: ' . $s . "\n";
}

// ----------------------------------------------------------------------
function extractVersion($s)
// ----------------------------------------------------------------------
{
  $ret = '';

  if ( preg_match("/mysql-(\d{1,2}\.\d{1,2}\.\d{1,2})/", $s, &$matches) ) {
    $ret = $matches[1];
  }

  return $ret;
}

// ----------------------------------------------------------------------
function start_database($aInstance)
// ----------------------------------------------------------------------
{
  $rc = 0;

  $cmd = '';
  $cmd .= 'cd ' . $aInstance['basedir'] . " ; ";
  $cmd .= "nohup bin/mysqld_safe --defaults-file=" . $aInstance['my.cnf'] . " --datadir=" . $aInstance['datadir'] . " --basedir=" . $aInstance['basedir'] . ' >/dev/null 2>&1 & echo $!' . "  ";
  debug($cmd);
  $stdout = shell_exec($cmd);

  if ( $ret != 0 ) {
    error("Command $cmd failed.");
    $rc = 12;
    // no return here
  }

  for ( $i = 1; $i <= 60 ; $i++ ) {
    $rc = check_database($aInstance);
    echo ".";
    if ( $rc == 0 ) {
    echo "\n";
      break;
    }
    sleep(1);
  }
  return $rc;
}

// ----------------------------------------------------------------------
function check_database($aInstance)
// ----------------------------------------------------------------------
{
  $rc = 0;

  $cmd = $aInstance['basedir'] . "/bin/mysqladmin -uroot ping --socket=" . $aInstance['socket'] . " >/dev/null 2>&1";
  debug($cmd);
  $stdout = exec($cmd, &$output, &$ret);

  if ( $ret != 0 ) {
    $rc = 14;
    // no return here
  }

  return $rc;
}

// ----------------------------------------------------------------------
function stop_database($aInstance)
// ----------------------------------------------------------------------
{
  $rc = 0;

  $cmd = $aInstance['basedir'] . "/bin/mysqladmin -uroot shutdown --socket=" . $aInstance['socket'];
  debug($cmd);
  $stdout = exec($cmd, &$output, &$ret);
  if ( $ret != 0 ) {
    error("Command $cmd failed.");
    $rc = 13;
    // no return here
  }

  return $rc;
}

# ----------------------------------------------------------------------
function getSchemaNames($pDatadir)
# Parameter     : $_[0] data directory
# Return values : hash of schema names
# ----------------------------------------------------------------------
{
  $aSchema = array();

  foreach ( glob("$pDatadir/*", GLOB_ONLYDIR) as $schema ) {
    if ( preg_match(':([^/]+)$:', $schema, &$match) ) {
      array_push($aSchema, $match[1]);
    }
  }

  return $aSchema;
}

# ----------------------------------------------------------------------
function addDirectoryToPath($lPath, $lDir, $lOldDir)
# Parameter     : $_[0] $PATH
#                 $_[1] new dir
# Return values : new $PATH
# ----------------------------------------------------------------------
{

  $lPath = str_replace($lDir, '', $lPath);
  $lPath = str_replace($lOldDir, '', $lPath);
  $lPath = $lDir . ':' . $lPath;
  $lPath = preg_replace('/:+/', ':', $lPath);
  $lPath = trim($lPath, ':');

  return $lPath;
}

// ----------------------------------------------------------------------
function getSectionTitles($a)
// ----------------------------------------------------------------------
{
  $aDbNames = array();
  foreach ( $a as $db => $value ) {

    if ( $db != 'default' ) {
      array_push($aDbNames, $db);
    }
  }
  return $aDbNames;
}

// ----------------------------------------------------------------------
function printStartingDatabases()
// ----------------------------------------------------------------------
{
  $lDebug         = intval($_ENV['DEBUG']);
  $basedir        = $_ENV['MYENV_BASE'];
  $lConfFile      = $basedir . '/etc/myenv.conf';
  $aConfiguration = parse_ini_file($lConfFile, true);

  if ( $lDebug ) {
    var_dump($aConfiguration);
  }

  $aDbNames = array();
  foreach ( $aConfiguration as $db => $parameter ) {

    if ( $db != 'default' ) {
      foreach ( $parameter as $key => $value ) {

        if ( ($key == 'start') && ((strtoupper($value) == 'YES' ) || ($value == 1)) ) {
          array_push($aDbNames, $db);
        }
      }
    }
  }
  return $aDbNames;
}

?>
